# Table of Contents

- [calculations-and-automations-when-to-use-each-feature](<./calculations-and-automations-when-to-use-each-feature.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Calculations and Automations: When to Use Each Feature](<./Calculations-and-Automations-When-to-Use-Each-Feature.md>)
  - [Overview](<./Calculations-and-Automations-When-to-Use-Each-Feature/Overview.md>)
  - [Feature Comparison](<./Calculations-and-Automations-When-to-Use-Each-Feature/Feature-Comparison.md>)
  - [Choosing a Feature for Updating Fact Sheet Fields](<./Calculations-and-Automations-When-to-Use-Each-Feature/Choosing-a-Feature-for-Updating-Fact-Sheet-Fields.md>)
  - [Examples](<./Calculations-and-Automations-When-to-Use-Each-Feature/Examples.md>)
